==> neqsim-3.0.0-py3-none-any.whl: neqsim/process/measurement.py <==
from neqsim import jneqsim
import jpype
import jpype.imports
from jpype import JImplements, JOverride


# Ensure the JVM is started and neqsim is attached
# Assuming you have already started the JVM with neqsim on the classpath
# If not, you'll need to start it before this code


@JImplements(
    jneqsim.processsimulation.measurementdevice.MeasurementDeviceInterface
)  # Use the fully qualified class name directly from the jneqsim package
class measurement:
    def __init__(self):
        self.name = ""
        self.unit = ""
        self.maximumValue = None
        self.minimumValue = None
        self.logging = False
        self.isOnlineSignal = False
        self.isMeasuredPercentValue = False
        self.isMeasuredValue = False

    @JOverride  # Add the missing 'equals' method
    def equals(self, obj):
        # Implement your equality logic here.
        # For example, you might compare the names of the objects:
        if isinstance(obj, unitop):
            return self.name == obj.name
        return False

    @JOverride  # Implement the missing 'hashCode' method
    def hashCode(self):
        # Implement your hash code logic here.
        # A simple example is to return the hash of the object's name:
        return hash(self.name)

    @JOverride  # Implement the missing 'displayResult' method
    def displayResult(self):
        # Add the logic to calculate or retrieve the pressure.
        # This will depend on how pressure is handled in your 'unitop' class.
        return 0.0  # Replace 0.0 with the actual pressure value or calculatio
        # Add the logic to calculate or retrieve the pressure.

    @JOverride  # Implement the missing 'getMeasuredValue' method
    def getMeasuredValue(self):
        return 0.0  # Replace 0.0 with the actual pressure value or calculatio

    @JOverride  # Implement the missing 'getOnlineSignal' method
    def getOnlineSignal(self):
        return 0.0

    @JOverride  # Implement the missing 'getMeasuredPercentValue' method
    def getMeasuredPercentValue(self):
        return 0.0

    @JOverride  # Implement the missing 'getMeasuredPercentValue' method
    def getUnit(self):
        return self.unit

    @JOverride  # Implement the missing 'getMeasuredPercentValue' method
    def setUnit(self, unitl):
        self.unit = unitl

    @JOverride  # Implement the missing 'getMaximumValue' method
    def getMaximumValue(self):
        return self.maximumValue

    @JOverride  # Implement the missing 'setMaximumValue' method
    def setMaximumValue(self, val):
        self.maximumValue = val

    @JOverride  # Implement the missing 'getMinimumValue' method
    def getMinimumValue(self):
        return self.minimumValue

    @JOverride  # Implement the missing 'setMinimumValue' method
    def setMinimumValue(self, val):
        self.minimumValue = val

    @JOverride  # Implement the missing 'isLogging' method
    def isLogging(self):
        return self.logging

    @JOverride  # Implement the missing 'setLogging' method
    def setLogging(self, val):
        self.logging = val

    @JOverride  # Implement the missing 'isOnlineSignal' method
    def isOnlineSignal(self):
        return self.isOnlineSignal

    @JOverride
    def getName(self):
        return self.name

    @JOverride
    def setName(self, name):
        self.name = name

==> neqsim-3.0.6-py3-none-any.whl: neqsim/process/measurement.py <==
from neqsim import jneqsim
import jpype
import jpype.imports
from jpype import JImplements, JOverride


# Ensure the JVM is started and neqsim is attached
# Assuming you have already started the JVM with neqsim on the classpath
# If not, you'll need to start it before this code


@JImplements(
    jneqsim.process.measurementdevice.MeasurementDeviceInterface
)  # Use the fully qualified class name directly from the jneqsim package
class measurement:
    def __init__(self):
        self.name = ""
        self.unit = ""
        self.maximumValue = None
        self.minimumValue = None
        self.logging = False
        self.isOnlineSignal = False
        self.isMeasuredPercentValue = False
        self.isMeasuredValue = False

    @JOverride  # Add the missing 'equals' method
    def equals(self, obj):
        # Implement your equality logic here.
        # For example, you might compare the names of the objects:
        if isinstance(obj, unitop):
            return self.name == obj.name
        return False

    @JOverride  # Implement the missing 'hashCode' method
    def hashCode(self):
        # Implement your hash code logic here.
        # A simple example is to return the hash of the object's name:
        return hash(self.name)

    @JOverride  # Implement the missing 'displayResult' method
    def displayResult(self):
        # Add the logic to calculate or retrieve the pressure.
        # This will depend on how pressure is handled in your 'unitop' class.
        return 0.0  # Replace 0.0 with the actual pressure value or calculatio
        # Add the logic to calculate or retrieve the pressure.

    @JOverride  # Implement the missing 'getMeasuredValue' method
    def getMeasuredValue(self):
        return 0.0  # Replace 0.0 with the actual pressure value or calculatio

    @JOverride  # Implement the missing 'getOnlineSignal' method
    def getOnlineSignal(self):
        return 0.0

    @JOverride  # Implement the missing 'getMeasuredPercentValue' method
    def getMeasuredPercentValue(self):
        return 0.0

    @JOverride  # Implement the missing 'getMeasuredPercentValue' method
    def getUnit(self):
        return self.unit

    @JOverride  # Implement the missing 'getMeasuredPercentValue' method
    def setUnit(self, unitl):
        self.unit = unitl

    @JOverride  # Implement the missing 'getMaximumValue' method
    def getMaximumValue(self):
        return self.maximumValue

    @JOverride  # Implement the missing 'setMaximumValue' method
    def setMaximumValue(self, val):
        self.maximumValue = val

    @JOverride  # Implement the missing 'getMinimumValue' method
    def getMinimumValue(self):
        return self.minimumValue

    @JOverride  # Implement the missing 'setMinimumValue' method
    def setMinimumValue(self, val):
        self.minimumValue = val

    @JOverride  # Implement the missing 'isLogging' method
    def isLogging(self):
        return self.logging

    @JOverride  # Implement the missing 'setLogging' method
    def setLogging(self, val):
        self.logging = val

    @JOverride  # Implement the missing 'isOnlineSignal' method
    def isOnlineSignal(self):
        return self.isOnlineSignal

    @JOverride
    def getName(self):
        return self.name

    @JOverride
    def setName(self, name):
        self.name = name
